@@ -15,7 +15,7 @@
 # OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 # PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: isc-config.sh.in,v 1.10.12.3 2004/03/08 04:04:12 marka Exp $
+# $Id: isc-config.sh.in,v 1.15 2004/03/05 04:56:57 marka Exp $
 
 prefix=/usr
 exec_prefix=${prefix}
@@ -69,7 +69,7 @@ while test $# -gt 0; do
 		echo_exec_prefix=true
 		;;
 	--version)
-		echo VERSION=9.3.2
+		echo VERSION=9.4.0
 		exit 0
 		;;
 	--cflags)
@@ -117,7 +117,7 @@ fi
 if test x"$echo_cflags" = x"true"; then
 	includes="-I${exec_prefix}/include"
 	if test x"$libisc" = x"true"; then
-		includes="$includes -D_REENTRANT   "
+		includes="$includes    "
 	fi
 	echo $includes
 fi
@@ -143,7 +143,7 @@ if test x"$echo_libs" = x"true"; then
 		needothers=true
 	fi
 	if test x"$needothers" = x"true" ; then
-		libs="$libs  -lnsl -lpthread "
+		libs="$libs  -lnsl "
 	fi
 	echo $libs
 fi
